mot\.cl\_routines\.optimizing package
=====================================

Submodules
----------

mot\.cl\_routines\.optimizing\.base module
------------------------------------------

.. automodule:: mot.cl_routines.optimizing.base
    :members:
    :undoc-members:
    :show-inheritance:

mot\.cl\_routines\.optimizing\.levenberg\_marquardt module
----------------------------------------------------------

.. automodule:: mot.cl_routines.optimizing.levenberg_marquardt
    :members:
    :undoc-members:
    :show-inheritance:

mot\.cl\_routines\.optimizing\.multi\_step\_optimizer module
------------------------------------------------------------

.. automodule:: mot.cl_routines.optimizing.multi_step_optimizer
    :members:
    :undoc-members:
    :show-inheritance:

mot\.cl\_routines\.optimizing\.nmsimplex module
-----------------------------------------------

.. automodule:: mot.cl_routines.optimizing.nmsimplex
    :members:
    :undoc-members:
    :show-inheritance:

mot\.cl\_routines\.optimizing\.powell module
--------------------------------------------

.. automodule:: mot.cl_routines.optimizing.powell
    :members:
    :undoc-members:
    :show-inheritance:

mot\.cl\_routines\.optimizing\.random\_restart module
-----------------------------------------------------

.. automodule:: mot.cl_routines.optimizing.random_restart
    :members:
    :undoc-members:
    :show-inheritance:

mot\.cl\_routines\.optimizing\.sbplex module
--------------------------------------------

.. automodule:: mot.cl_routines.optimizing.sbplex
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: mot.cl_routines.optimizing
    :members:
    :undoc-members:
    :show-inheritance:
